//
//  BLEManage.h
//  
//
//  Created by femto01 on 15/11/20.
//  Copyright © 2015 WTT. All rights reserved.
//

/**
 *  #define kBLEM [BLEManager sharedBLEManager]
    if (kBLEM.isConnected) {
        [kBLEM writeDataToDevice:@[@(0)] command:1];
        [kBLEM writeDataToDevice:@[@(1),@(2)] command:2];
    }
 *
 *
 */

#import <Foundation/Foundation.h>
#import <CoreBluetooth/CoreBluetooth.h>
@class BLEManager;

//Scan  device callback block
typedef void (^BleManagerDiscoverPeripheralCallBack) (NSArray *peripherals);
typedef void (^BleManagerConnectPeripheralCallBack) (BOOL isConnected);
typedef void (^BleManagerReceiveCallBack) (CBCharacteristic *characteristic );


/**
 BLEManagerDelegate
 */
@protocol BLEManagerDelegate <NSObject>
// Discovery peripherals
- (void)BLEManagerDelegate:(BLEManager *)BLEmanager updatePeripheralList:(NSArray *)peripherals RSSIList:(NSArray *)RSSIArr;
// connect successed
- (void)BLEManagerDelegate:(BLEManager *)BLEmanager connectPeripheral:(CBPeripheral *)peripheral;
//  disconnect peripherals
- (void)BLEManagerDelegate:(BLEManager *)BLEmanager disconnectPeripheral:(CBPeripheral *)peripheral isAutoDisconnect:(BOOL)isAutoDisconnect;
//  connect fail
- (void)BLEManagerDelegate:(BLEManager *)BLEmanager didFailToConnectPeripheral:(CBPeripheral *)peripheral error:(NSError *)error;

//- (void)BLEManagerDelegate:(BLEManager *)BLEmanager didReceiveDataFromPrinter:(CBCharacteristic *)characteristic;
// Send data successfully
- (void)BLEManagerDelegate:(BLEManager *)BLEmanager didWriteValueForCharacteristic:(CBCharacteristic *)character error:(NSError *)error;
@end


@interface BLEManager : NSObject <CBCentralManagerDelegate, CBPeripheralDelegate> {
    CBCharacteristic *write_characteristic;
    CBCharacteristic *read_characteristic;
    int commandSendMode; //Command send mode 0: send 1 immediately: send in bulk
}

#pragma mark -

@property (nonatomic,assign) id<BLEManagerDelegate> delegate;

#pragma mark  attribute

@property (strong, nonatomic) CBCentralManager *manager;        //BLE manager

@property (strong, nonatomic) CBPeripheral     *peripheral;   //Peripheral Bluetooth hardware

@property (nonatomic,assign ) BOOL             isConnected;   //is connect= yes，disconnect=no

@property (nonatomic,assign ) BOOL             isAutoDisconnect;  //isAutoDisconnect

@property (atomic,assign    ) BOOL           connectStatu;//  status of connect

@property (strong, nonatomic  ) NSMutableArray     *peripherals;// All hardware devices found

@property (strong, nonatomic) NSMutableArray *connectedPeripherals;//connectedPeripherals

@property (strong, nonatomic) NSMutableArray *RSSIArray;// Bluetooth signal array

@property (assign, readonly) BOOL isScaning; //isScaning

// Send data to the  peripheral
@property (nonatomic,strong) CBPeripheral *writePeripheral;
/**
 * Completion block for peripheral scanning
 */
@property (copy, nonatomic) BleManagerDiscoverPeripheralCallBack scanBlock;

@property (nonatomic,strong) NSMutableArray *dataArray;
@property (nonatomic,strong) NSMutableArray *commandBuffer;
/*
 *Connect Bluetooth callback
 */
@property (copy, nonatomic) BleManagerConnectPeripheralCallBack connectBlock;
/*
 *Receive data callback
 */
@property (nonatomic,copy) BleManagerReceiveCallBack receiveBlock;
#pragma mark -
#pragma mark   function
/**
 *  singleton method
 *
 *  @return self
 */
+ (instancetype)sharedBLEManager;

/*
 *  Get Bluetooth status
 */
- (BOOL)isLECapableHardware;

/**
 *  start scan
 */
- (void)startScan;

/*
 *   start scan stop at interval
 */
- (void)startScanWithInterval:(NSInteger)scanInterval completion:(BleManagerDiscoverPeripheralCallBack)callBack;

/**
 *  stop scan
 */
- (void)stopScan;

/**
 *   connect the periphral
 */
- (void)connectPeripheral:(CBPeripheral *)peripheral;

/*
 *   connect peripheral
 */
- (void)connectPeripheral:(CBPeripheral *)peripheral completion:(BleManagerConnectPeripheralCallBack)callBack;

/*
 *   reconnect the peripheral
 */
- (void)reConnectPeripheral:(CBPeripheral *)peripheral;

/**
 *   disconnect the peripheral
 */
- (void)disconnectPeripheral:(CBPeripheral *)peripheral;


#pragma mark -
#pragma mark  Custom other properties
/**
 *  Write data to a device
 *
 *  @param dataArray data for send
 *  @param command   Command value 1= message reminder, 2= running target, 3= running target when the lights remind, 4= set a low battery lights remind, 5= set light color 6= lights normally open, normally open, normally open mode 7= lights, 8= time setting device
 */
//- (void)writeDataToDevice:(NSArray *)dataArray command:(int)command;

/**
 The data is sent to the device, and the data sent is of type NSString, and the encoding type is specified
 */
-(void)sendDataWithPeripheral:(CBPeripheral *)peripheral withString:(NSString *)dataString coding:(NSStringEncoding)EncodingType;

/**
 Send command to printers
 */
-(void)writeCommadnToPrinterWthitData:(NSData *)data;

/**
 Send command to printer, with callback method
 */
-(void)writeCommadnToPrinterWthitData:(NSData  *)data withResponse:(BleManagerReceiveCallBack)block;



-(void)reScan;  /**Disconnect the existing equipment for re scanning*/

-(void)disconnectRootPeripheral;  //Disconnect existing device


/**
 * 32. get buffer
 */
-(NSArray*)GetBuffer;
/**
 * 33.clear buffer
 */
-(void)ClearBuffer;
/**
 * 34.send command buffer
 */
-(void)SendCommandBuffer;
/**
 * 34.send command
 */
-(void)sendCommand:(NSData *)data;

- (void)XYSetCommandMode:(int)Mode;
@end

