//
//  XYWIFIManager.h
//  Printer
//
//  Created by apple on 16/4/5.
//  Copyright © 2016年 Admin. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <UIKit/UIKit.h>
@class POSWIFIManager;
typedef void(^POSWIFIBlock)(BOOL isConnect);
typedef void(^POSWIFICallBackBlock)(NSData *data);
enum {
    SocketOfflineByServer,//  socket offline by server ,default:0
    SocketOfflineByUser,  //  socket offline by client
};

/**
 * Connect multiple devices
 *  use XYWIFIManager *manager = [[XYWIFIManager alloc] init]  init，
 * Save the manager and send the instruction to specify the corresponding manager send command
 */
@protocol POSWIFIManagerDelegate <NSObject>

//  connect the host
- (void)POSWIFIManager:(POSWIFIManager *)manager didConnectedToHost:(NSString *)host port:(UInt16)port;
//  disconnect the host
- (void)POSWIFIManager:(POSWIFIManager *)manager willDisconnectWithError:(NSError *)error;
//  write date to the device
- (void)POSWIFIManager:(POSWIFIManager *)manager didWriteDataWithTag:(long)tag;
//  Received return
- (void)POSWIFIManager:(POSWIFIManager *)manager didReadData:(NSData *)data tag:(long)tag;
//  wifi manager disconnect
- (void)POSWIFIManagerDidDisconnected:(POSWIFIManager *)manager;
@end

@interface POSWIFIManager : NSObject
{
    int commandSendMode; //Command send mode 0: send immediately, 1: batch send
}
#pragma mark - host attribute
//  host address
@property (nonatomic,copy) NSString *hostStr;
//  port
@property (nonatomic,assign) UInt16 port;
//  is the connection successful?
@property (nonatomic,assign) BOOL connectOK;
//  is auto disconnect
@property (nonatomic,assign) BOOL isAutoDisconnect;

@property (nonatomic,weak) id<POSWIFIManagerDelegate> delegate;
//  connect callback
@property (nonatomic,copy) POSWIFIBlock callBack;
//  Receive the data returned by the server
@property (nonatomic,copy) POSWIFICallBackBlock callBackBlock;
//command buffer
@property (nonatomic,strong) NSMutableArray *commandBuffer;

#pragma mark -  basic function
+ (instancetype)shareWifiManager;
// connect the host
-(void)POSConnectWithHost:(NSString *)hostStr port:(UInt16)port completion:(POSWIFIBlock)block;
//  disconnect
- (void)POSDisConnect;

// send command
-(void)POSWriteCommandWithData:(NSData *)data;

-(void)POSWriteCommandWithData:(NSData *)data withResponse:(POSWIFICallBackBlock)block;


- (void)POSSendMSGWith:(NSString *)str;


- (void)POSSetCommandMode:(BOOL)Mode;

/*
 * 74.Set printer send command mode
 * range: 0,1
 * 0: send immediately
 * 1: bulk delivery
 */

-(NSArray*)POSGetBuffer;
/*
 * 75.Returns the queue waiting for the transmit command
 */

-(void)POSClearBuffer;
/*
 * 76.Empty queue waiting for send command
 */

-(void)POSSendCommandBuffer;
/*
 * 77.command buffer for send
 */


@end
