//
//  PosCommand.h
//  Printer
//
//  Created by LeeLee on 16/7/19.
//  Copyright © 2016 Admin. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "ImageTranster.h"

/**
 The POS instruction class, which calls its class method, returns data of type Nsdata for sending, and this class applies only to POS printers
 */
@interface PosCommand : NSObject

/**
 Horizontal position<br>
 HT<br>
 09<br>
 */
+(NSData *) horizontalPosition;
/**
 print and feedline<br>
 LF<br>
 0A<br>
 */
+(NSData *) printAndFeedLine;
/**
  print and back to standar model<br>
 FF<br>
 OC<br>
 */
+(NSData *) printAndBackStandardModel;
/**
  print and tab<br>
 CR<br>
 0D<br>
 */
+(NSData *) printAndTabs;
/**
  cancle print data by pagemodel<br>
 CAN<br>
 18<br>
 */
+(NSData *) canclePrintDataByPageModel;
/**
  send realtime status<br>
 DLE EOT n<br>
 10 04 n<br>
 (int) n: 1<=n<=4.<br>
 */
+(NSData *) sendRealTimeStatus:(int) n;
/**
  request realtime for printer<br>
 DLE ENQ n<br>
 10 05 n<br>
 (int) n: 1<=n<=2.<br>
 */
+(NSData *) requestRealTimeForPrint:(int) n;
/**
 Open the box of the pulse <br>
 DLE DC4 n m t<br>
 10 14 01 m t<br>
 (int) m: m=0,or 1；<br>
 (int) t: 1<=t<=8.<br>
 */
+(NSData *) openCashBoxRealTimeWithM:(int) m andT:(int) t;
/**
  Print under pagemodel<br>
 ESC FF<br>
 1B 0C<br>
 This command is valid only in page mode<br>
 */
+(NSData *) printUnderPageModel;
/**
  set char right space <br>
 1B 20 n<br>
 (int) n: 0~255,in dots.<br>
 */
+(NSData *) setCharRightSpace:(int) n;
/**
  select print model<br>
 ESC !n<br>
 1B 21 n<br>
 (int) n: 0~255,Only the last n is valid, the 0 represents cancellation, and the 1 represents choice.<br>
 */
+(NSData *) selectPrintModel:(int) n;
/**
  set absolute position of printer<br>
 ESC $ nL nH<br>
 1B 24 nL nH<br>
 nL+nH*256 On behalf of the position of the distance<br>
 */
+(NSData *) setAbsolutePrintPositionWithNL:(int) nL andNH:(int) nH;
/**
  select or cancle customchar<br>
 ESC % n<br>
 1B 25 n<br>
 (int) n: 0~255,Only the last n is valid, the 0 represents cancellation, and the 1 represents choice.<br>
 */
+(NSData *) selectOrCancleCustomChar:(int) n;
/**
 define user defined character
 ESC * m nL nH d1 d2 ...dk<br>
 (int) c1:  begin<br>
 (int) c2:  end，32<=c1<=c2<=127<br>
 (Byte*) bytes: data<br>
 */
+(NSData *) defineUserDefinedCharactersWithM:(int) m andNL:(int) nL andNH:(int) nH andBytes:(Byte *) bytes;
/**
 select bitmap model<br>
 ESC * m nL nH d1 d2 ...dk<br>
 m ：0，1，32，33，Representing densities of different points<br>
 nL：0-255<br>
 nH：0-3<br>
 b={d1,d2...dk},m=0,1；k=nL+256*nH;m=32,33，k=(nL+256*nH)*3;d:0-255;<br>
 */
+(NSData *) selectBmpModelWithM:(int) m andnL:(int) nL andnH:(int) nH andNSData:(NSData *) data;
/**
  Select or cancel underline model<br>
 ESC-n<br>
 1B 2D n<br>
 (int) n:0 or 48 cancel;1 or 49 select(by 1 dot);2 or 50 select (by 2 dots).<br>
 */
+(NSData *) selectOrCancleUnderLineModel:(int) n;
/**
  set defulte line space <br>
 ESC 2<br>
 */
+(NSData *) setDefultLineSpace;
/**
  set defult line space<br>
 ESC 3 n<br>
 1B 33 n<br>
 */
+(NSData *) setDefultLineSpace:(int) n;
/**
  select printer<br>
 ESC = n<br>
 1B 3D n<br>
 n:0 or 1<br>
 */
+(NSData *) selectPrinter:(int) n;
/**
  cancel user defined characters<br>
 ESC ? n<br>
 Cancel characters in user defined characters whose code is n<br>
 n ：32-127<br>
 */
+(NSData *) cancleUserDefinedCharacters:(int) n;
/**
  initialize the printer<br>
 ESC @<br>
 1B 40<br>
 */
+(NSData *) initializePrinter;
/**
  set horizontal tabs position<br>
 ESC D n1 ...nk NUL<br>
 data={n1...nk};k<=32;tabs width=chars width*k<br>
 Refer to the programming manual for the N and K values in the parameter data<br>
 */
+(NSData *) setHorizontalTabsPosition:(NSData *) data;
/**
  select or cancel bold model<br>
 ESC E n<br>
 1B 45 n<br>
 (int) n: 0~255,Only the last n is valid, the 0 represents cancellation, and the 1 represents choice.<br>
 */
+(NSData *) selectOrCancleBoldModel:(int) n;
/**
  select or cancel double print model<br>
 ESC G n<br>
 1B 47 n<br>
 (int) n: 0~255,Only the last n is valid, the 0 represents cancellation, and the 1 represents choice.<br>
 */
+(NSData *) selectOrCancleDoublePrintModel:(int) n;
/**
  print and feed<br>
 ESC J n<br>
 1B 4A n<br>
 (int) n: specify the length(in inch) feeds.
 */
+(NSData *) printAdnFeed:(int) n;
/**
  select page model<br>
 ESC L<br>
 1B 4C<br>
 
 */
+(NSData *) selectPagemodel;
/**
  select font<br>
 ESC M n<br>
 1B 4D n<br>
 n ： 0，1，48，49；<br>
 */
+(NSData *) selectFont:(int) n;
/**
  select international character sets<br>
 ESC R n<br>
 n:0-15，Represents an international character set<br>
 1B 52 n<br>
 */
+(NSData *) selectInternationCharacterSets:(int) n;
/**
  select standard model<br>
 ESC S<br>
 1B 53<br>
 */
+(NSData *) selectStabdardModel;
/**
  select print direction under pagemodel<br>
 ESC T n<br>
 1B 54 n<br>
 (int) n: 0<=n<=3 or 48<=n<=51;n specifies the direction and starting position of the print area。<br>
 */
+(NSData *) selectPrintDirectionUnderPageModel:(int) n;
/**
 Select or cancel clockwise rotation of 90 degrees <br>
 This command is valid only in page mode<br>
 ESC V n<br>
 1B 56 n<br>
 (int) n: n=0 or 48 cancel；n=1 or 49 Select.<br>
 */
+(NSData *) selectOrCancleCW90:(int) n;
/**
  Set print area in page mode<br>
 ESC W xL xH yL yH dxL dxH dyL dyH<br>
 1B 57 xL xH yL yH dxL dxH dyL dyH<br>
 xL+xH*256 Represents the starting position of the X direction <br>
 yL+yH*256 Represents the starting position of the Y direction<br>
 dxL+dxH*256 Represents the width of the X direction<br>
 dyL+dyH*256 Represents the height of the Y direction<br>
 */
+(NSData *) setPrintAreaUnderPageModelWithxL:(int) xL
                                       andxH:(int) xH
                                       andyL:(int) yL
                                       andyH:(int) yH
                                      anddxL:(int) dxL
                                      anddxH:(int) dxH
                                      anddyL:(int) dyL
                                      anddyK:(int) dyH;
/**
 Sets the relative horizontal printing position<br>
 ESC \ nL nH<br>
 1B 5C nL nH<br>
 nL+nH*256 Represents the size of the setting<br>
 */
+(NSData *) setRelativeHorizontalPrintPositionWithnL:(int) nL andnH:(int) nH;
/**
 select aligment<br>
 ESC a n<br>
 1B 61 n<br>
 */
+(NSData *) selectAlignment:(int) n;
/**
  select print tranducer output`<br>
 ESC c 3 n<br>
 1B 63 33 n<br>
 (int) n:0~255.<br>
 */
+(NSData *) selectPrintTransducerOutPutPageOutSignal:(int) n;
/**
  select print transducer stop printing<br>
 ESC c 4 n<br>
 1B 63 34 n<br>
 (int) n:0~255.<br>
 */
+(NSData *) selectPrintTransducerStopPrint:(int) n;
/**
  allow or forbid press button<br>
 ESC c 5 n<br>
 1B 63 35 n<br>
 (int) n: Only the last n is valid, the 0 represents allow, and the 1 represents forbiden<br>
 */
+(NSData *) allowOrForbidPressButton:(int) n;
/**
  print and feed forward with n lines<br>
 ESC d n<br>
 1B 64 n<br>
 (int) n:0~255.<br>
 */
+(NSData *) printAndFeedForwardWhitN:(int) n;
/**
  create cashbox contorpulse<br>
 ESC p m t1 t2<br>
 1B 70 m t1 t2<br>
 (int) m:pins,0 or 1 or 48 or 49.<br>
 t1 ,t2 :0~255.<br>
 */
+(NSData *) creatCashBoxContorPulseWithM:(int) m andT1:(int) t1 andT2:(int) t2;
/**
  select charactercode page <br>
 ESC t n<br>
 1B 74 n<br>
 (int) n: 0~10 or 16~19<br>
 */
+(NSData *) selectCharacterCodePage:(int) n;
/**
  select or cancele convert print model<br>
 ESC { n<br>
 1B 7B n<br>
 (int) n: N last decision, 1 choices, 0 cancellation。<br>
 */
+(NSData *) selectOrCancleConvertPrintModel:(int) n;
/**
   print bitmap in flash<br>
 FS p n m<br>
 (int) n:  N represents the image at the N position in the FLASH cache<br>
 (int) m:  Represents the way to print FLASH bitmaps，0~3 or 48~51，They represent normal, double width, double height and double width。<br>
 */
+(NSData *) printBmpInFLASHWithN:(int) n andM:(int) m;
/**
  defined flash bitmap <br>
 FS q n [xL xH yL yH d1...dk]...[xL xH yL yH d1...dk]<br>
 1C 71 n data<br>
 n: the number of bitmap<br>
 data=[xL xH yL yH d1...dk]...[xL xH yL yH d1...dk]，Data representing multiple bitmaps ，each bitmap  contains :xL xH yL yH refers the width and height<br>
 */
+(NSData *) definedFlashBmpWithN:(int) n andBmp:(UIImage *) image andBmpType:(BmpType) bmptype andPrintType:(PrintRasterType) type andPaperHeight:(int) paperheight;
/**
  select character size <br>
 GS ! n<br>
 (int) n:0~255,N's 0-3 bit set character height, 4-7 to set the character width。<br>
 */
+(NSData *) selectCharacterSize:(int) n;
/**
  set absolute position under page model<br>
 GS $ nL nH<br>
 1D 24 nL nH<br>
 nL ,nH ranges：0~255，nL+nH*256 refers the position，单位inch<br>
 */
+(NSData *) setAbsolutePositionUnderPageModelWithnL:(int) nL andnH:(int) nH;
/**
  defined dowload bitmap<br>
 GS x y[d1...d(8*xy)]<br>
 1D 2A data<br>
 (UIImage*) image :image object <br>
 */
+(NSData *) definedDownLoadBmp:(UIImage *) image byType:(BmpType) bmptype andPaperHeight:(int) paperheight;
/**
  execute print data saving by teans form to Hex<br>
 GS ( A pL pH n m<br>
 1D 28 41 02 00 00 01<br>
 */
+(NSData *) executePrintDataSavaByTeansformToHex;
/**
  print dowload bitmap<br>
 GS / m<br>
 1D 2F m<br>
 (int) m:model for printing，ranges：0~3 or 48~51.<br>
 */
+(NSData *) printDownLoadBmp:(int) m;
/**
 start or stop macro definition<br>
 GS :<br>
 1D 3A<br>
 */
+(NSData *) startOrStopMacrodeFinition;
/**
  select or cancle unvert print model<br>
 GS B n<br>
 1D 42 n<br>
 (int) n: The last option for n is 1, with 0 cancellation.<br>
 */
+(NSData *) selectOrCancleInvertPrintModel:(int) n;
/**
  select the position of HRI character<br>
 GS H n<br>
 1D 48 n<br>
 (int) n:0~3 or 48~51, Represents the print position of the characters relative to the barcode。<br>
 */
+(NSData *) selectHRICharactersPrintPosition:(int) n;
/**
  set left space <br>
 GS L nL nH<br>
 1D 4C nL nH<br>
 (nL+nH*256)* A horizontal moving unit that represents the left distance of the setting，unit：inch.<br>
 */
+(NSData *) setLeftSpaceWithnL:(int) nL andnH:(int) nH;
/**
  set horizattal and vertical movement<br>
 GS P x y<br>
 1D 50 x y<br>
 (int) x:  horizatal move，0~255.<br>
 (int) y:  vertical move，0~255.<br>
 */
+(NSData *) setHorizontalAndVerticalMoveUnitWithX:(int) x andY:(int) y;
/**
  select cut page model and cut page<br>
 GS V m<br>
 1D 56 m<br>
 (int) m:0 or 48, all cut;1 or 49，half  cut.<br>
 */
+(NSData *) selectCutPageModelAndCutpage:(int) m;

/**
  select cut page model and cut page<br>
 GS V m n<br>
 1D 56 m n<br>
 (int) m: m=66.<br>
 (int) n:  feed n，then half cut。<br>
 
 */
+(NSData *) selectCutPageModelAndCutpageWithM:(int) m andN:(int) n;
/**
  set print area <br>
 GS W nL nH<br>
 1D 57 nL nH<br>
 (nL+nH*256)* horizatal movement ， refers the width of area.<br>
 */
+(NSData *) setPrintAreaWidthWithnL:(int) nL andnH:(int) nH;
/**
  set vertical relative positon under page model<br>
 GS \ nL nH<br>
 1D 5C nL nH<br>
 (nL+nH*256)* A vertical unit of motion representing a longitudinal shift of distance relative to the current print position.<br>
 */
+(NSData *) setVertivalRelativePositionUnderPageModelWithNL:(int) nL andNH:(int) nH;
/**
  execute macrode command<br>
 GS ^ r t m<br>
 1D 5E r t m<br>
 (int) r:0~255,times.<br>
 (int) t:0~255,time of excuting waiting。<br>
 (int) m:0 or 1,model of excute<br>
 */
+(NSData *) executeMacrodeCommandWithR:(int) r andT:(int) t andM:(int) m;
/**
  open or close auto return print state<br>
 GS a n<br>
 1D 61 n<br>
 (int) n: 0~255, Each bit of N returns on behalf of a different type of state.<br>
 */
+(NSData *) openOrCloseAutoReturnPrintState:(int) n;
/**
  select HRI font<br>
 GS f n<br>
 1D 66 n<br>
 (int) n: 0 or 48 standar model；1 or 49  compresion model。<br>
 
 */
+(NSData *) selectHRIFont:(int) n;
/**
  set the height of barcode<br>
 GS h n<br>
 1D 68 n<br>
 (int) n: 1~255,defualt:162.<br>
 */
+(NSData *) setBarcodeHeight:(int) n;
/**
  print barcode<br>
 GS k m d1...dk NUL<br>
 1D 6B m d1...dk 00<br>
 (int) m:type ，0~6.<br>
 (NSString*) content: content of barcode。<br>
 
 */
+(NSData *) printBarcodeWithM:(int) m andContent:(NSString *) content useEnCodeing:(NSStringEncoding) strEncoding;

/**
  print barcode<br>
 GS k m n d1...dk<br>
 1D 6B m n d1...dk<br>
 (int) m:  type of barcode,66~73.<br>
 (int) n:  content of barcode。<br>
 */
+(NSData *) printBarcodeWithM:(int)m andN:(int) n andContent:(NSString *)content useEnCodeing:(NSStringEncoding) strEncoding;
/**
  returen state of printer<br>
 GS r n<br>
 1D 72 n<br>
 (int) n: 1,2,49,50;1 or 49 Return sensor status，2 or 50 Return to the state of the cashbox。<br>
 */
+(NSData *) returnState:(int) n;
/**
  print raste bitmap<br>
 GS V 0 m<br>
 (PrintRasterType) m:raster type。<br>
 (UIImage *) image: bitmap object。<br>
 (BmpType) type: deal with the bitmap , Dithering or Threshold<br>
 
 */
+(NSData *) printRasteBmpWithM:(PrintRasterType) m andImage:(UIImage *) image andType:(BmpType) type andPaperHeight:(int) paperheight;
/**
  set barcode width<br>
 GS w n<br>
 1D 77 n<br>
 (int) n:2~6,defualt 3.<br>
 */
+(NSData *) setBarcoeWidth:(int) n;
/**
  set chinese character model<br>
 FA ! n<br>
 1C 21 n<br>
 (int) n: 0~255, The different bits of N define character patterns。
 */
+(NSData *) setChineseCharacterModel:(int) n;
/**
  select chinese character model<br>
 FS &<br>
 1C 26<br>
 */

+(NSData *) selectChineseCharacterModel;
/**
  selct or cancel chinese char under line model<br>
 FS - n<br>
 1C 2D n<br>
 (int) n:0~2 or 48~50.<br>
 */

+(NSData *) selectOrCancelChineseCharUnderLineModel:(int) n;
/**
  cancel chinese char model<br>
 FS .<br>
 1C 2E<br>
 */

+(NSData *) CancelChineseCharModel;
/**
  defined user defined chinese char<br>
 FS 2 c1 c2 d1...dk<br>
 1C 32 FE c2 d1...dk<br>
 (int) c2: A1H<=c2<=FEH.<br>
 (Byte*) bytes: bytes[] of the char 。<br>
 */
+(NSData *) definedUserDefinedChineseCharWithCPosition:(int) c2 andNsdata:(Byte *) bytes;
/**
  set chinese char left and right space<br>
 FS S n1 n2<br>
 1C 53 n1 n2<br>
 (int) n1:left space ，0~255.<br>
 (int) n2: right space，0~255.<br>
 */
+(NSData *) setChineseCharLeftAndRightSpaceWithN1:(int) n1 andN2:(int) n2;
/**
 select or cancel double width and height of chinese char<br>
 FS W n<br>
 1C 57 n<br>
 (int) n:0~255, The lowest point of n is 1, representing selection, 0, and cancellation。<br>
 */

+(NSData *) selectOrCancelChineseCharDoubleWH:(int) n;
/**
   printer order buzzing hit<br>
 ESC B n t<br>
 1B 42 n t<br>
 (int) n:  times of buzzing hit，1~9.<br>
 (int) t: t*50ms: refers of every  time of buzzing hit ，1~9.<br>
 */
+(NSData *) printerOrderBuzzingHintWithRes:(int) n andTime:(int) t;
/**
  printer order buzzing and waring light<br>
 ESC C m t n<br>
 1B 43 m t n<br>
 (int) m: The number of beeps and the number of alarm lights flashing，1~20.<br>
 (int) t: (t*50ms) Represents interval time，1~20.<br>
 (int) n: 0~3, respectively, whether to tweet or flicker.<br>
 */
+(NSData *) printerOrderBuzzingAndWaringLightWithM:(int) m andT:(int) t andN:(int) n;
/**
 QRCODE: set QRcode unitsize<br>
 GS ( 0 g n<br>
 1D 28 6B 30 67 n<br>
 (int) n:0~255.<br>
 */

+(NSData *) setQRcodeUnitsize:(int) n;
/**
  set error correct level for QRcode<br>
 GS ( 0 i n<br>
 1D 28 6B 30 69 n<br>
 */

+(NSData *) setErrorCorrectionLevelForQrcode:(int) n;
/**
  send data to store area with QRcontent<br>
 GS ( 0 & nL nH d1...dk<br>
 1D 28 6B 30 80 nL nH d1...dk<br>
 (NSString *) str:  content of QRcode。<br>
 */

+(NSData *) sendDataToStoreAreaWitQrcodeConent:(NSString *) str usEnCoding:(NSStringEncoding) strEnCoding;
/**
  print the QRcode in storearea
 GS ( 0 ?<br>
 1D 28 6B 30 81<br>
 */

+(NSData *) printTheQRcodeInStore;

/**
 Set the number of columns in the data region<br>
 1D 28 6B 03 00 30 41 n<br>
 
 */

+(NSData *) setPdf417Columns:(int) n;

/**
 set the width of the moudule<br>
 1D 28 6B 03 00 30 43 n<br>
 
 */

+(NSData *) setpdf417WidthOfModule:(int) n;

/**
 set the row height<br>
 1D 28 6B 03 00 30 44 n<br>
 
 */

+(NSData *) setpdf417RowHeight:(int) n;

/**
 store the data in the symbol storage area<br>
 1D 28 68 F9 00 30 50 30 d1...dk<br>
 
 */
+(NSData *) storethepdf417WithpL:(int) pL andpH:(int) pH andContent:(NSString*) content usEnCoding:(NSStringEncoding) strEnCoding;

/**
 print the pdf417 symbol data in the symbol storage area<br>
 1D 28 6B 03 00 30 51 n<br>
 
 */

+(NSData *) printPdf417InStore;
@end
